@@ -19,7 +19,12 @@ from pydantic import BaseModel, Field, validator
 
 from datamodel_code_generator import snooper_to_methods
 from datamodel_code_generator.format import PythonVersion
-from datamodel_code_generator.imports import IMPORT_ANY, Import
+from datamodel_code_generator.imports import (
+    IMPORT_ANY,
+    IMPORT_DICT,
+    IMPORT_LIST,
+    Import,
+)
 from datamodel_code_generator.model import DataModel, DataModelFieldBase
 from datamodel_code_generator.model.enum import Enum
 
@@ -229,7 +234,7 @@ class JsonSchemaParser(Parser):
                         type=f"List[Union[{', '.join(types)}]]"
                         if len(types) > 1
                         else f"List[{types[0]}]",
-                        imports_=[Import(from_='typing', import_='List')],
+                        imports_=[IMPORT_LIST],
                     )
                 )
             else:
@@ -342,14 +347,33 @@ class JsonSchemaParser(Parser):
                             version_compatible=True,
                         )
                     ]
+                elif isinstance(field.additionalProperties, JsonSchemaObject):
+                    field_class_name = self.model_resolver.add(
+                        [*path, field_name], field_name, class_name=True
+                    ).name
+
+                    # TODO: supports other types
+                    if field.additionalProperties.is_array:
+                        parse_method = self.parse_array
+                    else:
+                        parse_method = self.parse_object
+                    additional_properties_type = parse_method(
+                        field_class_name,
+                        field.additionalProperties,
+                        [*path, field_name],
+                    ).name
+
+                    field_types = [
+                        self.data_type(
+                            type=f'Dict[str, {additional_properties_type}]',
+                            imports_=[IMPORT_DICT],
+                            unresolved_types=[additional_properties_type],
+                        )
+                    ]
                 else:
                     field_types = [
                         self.data_type(
-                            type='Dict[str, Any]',
-                            imports_=[
-                                Import(from_='typing', import_='Any'),
-                                Import(from_='typing', import_='Dict'),
-                            ],
+                            type='Dict[str, Any]', imports_=[IMPORT_ANY, IMPORT_DICT],
                         )
                     ]
             elif field.enum:
@@ -476,7 +500,9 @@ class JsonSchemaParser(Parser):
         )
         return field, item_obj_data_types
 
-    def parse_array(self, name: str, obj: JsonSchemaObject, path: List[str]) -> None:
+    def parse_array(
+        self, name: str, obj: JsonSchemaObject, path: List[str]
+    ) -> DataModel:
         field, item_obj_names = self.parse_array_fields(name, obj, [*path, name])
         self.model_resolver.add(path, name)
         data_model_root = self.data_model_root_type(
@@ -488,6 +514,7 @@ class JsonSchemaParser(Parser):
         )
 
         self.append_result(data_model_root)
+        return data_model_root
 
     def parse_root_type(
         self, name: str, obj: JsonSchemaObject, path: List[str]
